@@ -16,6 +16,11 @@ condmutinfo<-function(x,y,z)
  .Call(C_getMi,factor(x),factor(sprintf("%s%s",y,z)))-
  .Call(C_getMi,factor(x),factor(z))
 
+entro<-function(x){
+ table(x)/length(x)->p
+ sum(-ifelse(p>0,p*log(p),0))
+}
+
 cmutinfo<-function(a,b,c){
  a<-factor(a)
  b<-factor(b)
@@ -27,18 +32,21 @@ cmutinfo<-function(a,b,c){
 pureMIM<-function(X,Y,k=3){
  apply(X,2,mutinfo,Y)->mim
  sort(mim,decreasing=TRUE)[1:k]->ans
+ ans[ans>0]->ans
  list(
-  selection=names(ans),
-  score=setNames(ans,NULL)
+  selection=setNames(match(names(ans),names(X)),names(ans)),
+  score=ans
  )
 }
 
 pureCMIM<-function(X,Y,k=3){
+ nX<-names(X)
  X<-data.frame(X)
  ascores<-apply(X,2,mutinfo,Y)
  selection<-names(which.max(ascores))
  fscores<-max(ascores)
- scores<-rep(Inf,ncol(X))
+ #Conceptually wrong, but as defined by Fleuret
+ scores<-ascores
  if(k>1) for(e in 1:(k-1)){
   factor(X[,tail(selection,1)])->w
   scores[colnames(X)!=tail(selection,1)]->scores
@@ -48,16 +56,19 @@ pureCMIM<-function(X,Y,k=3){
    newScores,  
    scores
   )
+  if(max(scores)==0) break
+
   selection<-c(selection,names(which.max(scores)))
   fscores<-c(fscores,max(scores))
  }
  list(
-  selection=selection,
-  score=setNames(fscores,NULL)
+  selection=setNames(match(selection,nX),selection),
+  score=setNames(fscores,selection)
  )
 }
 
 pureJMIM<-function(X,Y,k=3){
+ nX<-names(X)
  X<-data.frame(X)
  ascores<-apply(X,2,mutinfo,Y)
  selection<-names(which.max(ascores))
@@ -78,12 +89,13 @@ pureJMIM<-function(X,Y,k=3){
   fscores<-c(fscores,max(scores))
  }
  list(
-  selection=selection,
-  score=setNames(fscores,NULL)
+  selection=setNames(match(selection,nX),selection),
+  score=setNames(fscores,selection)
  )
 }
 
 pureNJMIM<-function(X,Y,k=3){
+ nX<-names(X)
  X<-data.frame(X)
  ascores<-apply(X,2,mutinfo,Y)
  selection<-names(which.max(ascores))
@@ -104,12 +116,13 @@ pureNJMIM<-function(X,Y,k=3){
   fscores<-c(fscores,max(scores))
  }
  list(
-  selection=selection,
-  score=setNames(fscores,NULL)
+  selection=setNames(match(selection,nX),selection),
+  score=setNames(fscores,selection)
  )
 }
 
 pureJMI<-function(X,Y,k=3){
+ nX<-names(X)
  X<-data.frame(X)
  ascores<-apply(X,2,mutinfo,Y)
  selection<-names(which.max(ascores))
@@ -121,16 +134,18 @@ pureJMI<-function(X,Y,k=3){
   X[,colnames(X)!=tail(selection,1),drop=FALSE]->X
   scores+apply(X,2,function(xx) mutinfo(mergef(x,factor(xx)),Y))->scores
   if(max(scores)==0) break
+
   selection<-c(selection,names(which.max(scores)))
   fscores<-c(fscores,max(scores))
  }
  list(
-  selection=selection,
-  score=setNames(fscores,NULL)
+  selection=setNames(match(selection,nX),selection),
+  score=setNames(fscores,selection)
  )
 }
 
 pureMRMR<-function(X,Y,k=3){
+ nX<-names(X)
  X<-data.frame(X)
  rel<-apply(X,2,mutinfo,Y)
  red<-rep(0,ncol(X))
@@ -150,12 +165,13 @@ pureMRMR<-function(X,Y,k=3){
   fscores<-c(fscores,max(scores))
  }
  list(
-  selection=selection,
-  score=fscores
+  selection=setNames(match(selection,nX),selection),
+  score=setNames(fscores,selection)
  )
 }
 
 pureDISR<-function(X,Y,k=3){
+ nX<-names(X)
  X<-data.frame(X)
  ascores<-apply(X,2,mutinfo,Y)
  selection<-names(which.max(ascores))
@@ -173,8 +189,8 @@ pureDISR<-function(X,Y,k=3){
   fscores<-c(fscores,max(scores))
  }
  list(
-  selection=selection,
-  score=fscores
+  selection=setNames(match(selection,nX),selection),
+  score=setNames(fscores,selection)
  )
 }
 
